@@ -29,13 +29,13 @@ void cannadic_parse_line(unsigned char *buf, word **head) {
     /*
      * cannadic format:
      *
-     * phon cclass desc (desc desc ... ) (cclass desc (desc ...) ....)
+     * phon pos desc (desc desc ... ) (pos desc (desc ...) ....)
      *
      * phon  : must
-     * cclass: at least 1 entry
+     * pos   : at least 1 entry
      * desc  : at least 1 entry
      *
-     * cclass and desc must be associated with each other.
+     * pos and desc must be associated with each other.
      *
      */
     unsigned char *pos = NULL, *phonetic = NULL, *literal = NULL;
@@ -43,6 +43,11 @@ void cannadic_parse_line(unsigned char *buf, word **head) {
     unsigned char *tmp1 = NULL, *tmp2 = NULL;
     int freq = 1;
 
+    if(buf == NULL) {
+	*head = NULL;
+	return;
+    }
+
     if(buf[strlen(buf) - 1] == '\n') buf[strlen(buf) - 1] = '\0';
 
     cur = strchr(buf, ' ');
@@ -85,14 +90,16 @@ GList *cannadic_parse_line_glist(unsigned char *buf, GList *list) {
     /*
      * cannadic format:
      *
-     * phon cclass desc (desc desc ... ) (cclass desc (desc ...) ....)
+     * phon pos desc (desc desc ... ) (pos desc (desc ...) ....)
      *
      * phon  : must
-     * cclass: at least 1 entry
+     * pos   : at least 1 entry
      * desc  : at least 1 entry
      *
-     * cclass and desc must be associated with each other.
+     * pos and desc must be associated with each other.
      *
+     * XXX: pos is a part of speech in this document. But pos uses as cursor
+     *      in this code.
      */
     unsigned char *pos = NULL, *phonetic = NULL, *literal = NULL;
     unsigned char *cur = NULL, *cur1 = NULL;
@@ -102,6 +109,9 @@ GList *cannadic_parse_line_glist(unsigned char *buf, GList *list) {
     gint rbytes, wbytes;
     int freq = 1;
 
+    if(buf == NULL)
+	return NULL;
+
     if(buf[strlen(buf) - 1] == '\n') buf[strlen(buf) - 1] = '\0';
 
     cur = strchr(buf, ' ');
