@@ -31,11 +31,13 @@ static char *get_skkdicfullpath(void) {
     }
 
     skkdicfullpath = malloc(strlen(homedirectory) + strlen(skkdicname) + 2);
-    if(skkdicfullpath != NULL) {
-	snprintf(skkdicfullpath,
-		 strlen(homedirectory) + strlen(skkdicname) + 2,
-		 "%s/%s", homedirectory, skkdicname);
-    }
+    if(skkdicfullpath == NULL)
+	return NULL;
+
+    snprintf(skkdicfullpath,
+	     strlen(homedirectory) + strlen(skkdicname) + 2,
+	     "%s/%s", homedirectory, skkdicname);
+
     return skkdicfullpath;
 }
 
