@@ -84,8 +84,8 @@ GType addword_pane_get_type(void) {
 }
 
 static void addword_pane_class_init(AddWordPaneClass *klass) {
-    GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS(klass);
+    GObjectClass   *gobject_class = G_OBJECT_CLASS(klass);
+    GtkObjectClass *object_class  = GTK_OBJECT_CLASS(klass);
 
     parent_class = g_type_class_peek_parent(klass);
 
@@ -94,12 +94,11 @@ static void addword_pane_class_init(AddWordPaneClass *klass) {
     gobject_class->finalize = addword_pane_finalize;
     object_class->destroy = addword_pane_destroy;
 
-
     g_object_class_install_property(gobject_class,
 				    PROP_MODE,
 				    g_param_spec_int("mode",
-						     _(""),
-						     _(""),
+						     _("to be written"),
+						     _("to be written"),
 						     ADDWORDPANE_MODE_NOTHING,
 						     ADDWORDPANE_MODE_ALL,
 						     ADDWORDPANE_MODE_ALL,
@@ -117,6 +116,7 @@ static void addword_pane_init(AddWordPane *pane) {
     GtkWidget *label_freq;
     GtkWidget *menu_pos, *menuitem_pos;
     GtkWidget *frame_checkbox;
+    GtkAdjustment *adjustment_freq;
 
     gint i, num;
 
@@ -155,7 +155,7 @@ static void addword_pane_init(AddWordPane *pane) {
     gtk_widget_show(widget);
     pane->literal = GTK_ENTRY(widget);
 
-    label_pos_broad = gtk_label_new(_("Part of speech(broad):"));
+    label_pos_broad = gtk_label_new(_("Part of Speech(broad):"));
     gtk_misc_set_alignment(GTK_MISC(label_pos_broad), 1.0, 0.5);
     gtk_widget_show(label_pos_broad);
     gtk_table_attach(GTK_TABLE(table1), label_pos_broad,
@@ -180,7 +180,7 @@ static void addword_pane_init(AddWordPane *pane) {
     gtk_table_attach(GTK_TABLE(table1), alignment_pos,
 		     1, 2, 2, 3, GTK_FILL, GTK_FILL, 5, 5);
 
-    label_pos_narrow = gtk_label_new(_("Part of speech(narrow):"));
+    label_pos_narrow = gtk_label_new(_("Part of Speech(narrow):"));
     gtk_misc_set_alignment(GTK_MISC(label_pos_narrow), 1.0, 0.5);
     gtk_widget_show(label_pos_narrow);
     gtk_table_attach(GTK_TABLE(table1), label_pos_narrow,
@@ -206,13 +206,12 @@ static void addword_pane_init(AddWordPane *pane) {
     gtk_table_attach(GTK_TABLE(table1), label_freq,
 		     0, 1, 4, 5, GTK_FILL, 0, 5, 5);
 
-    widget = gtk_entry_new();
+    adjustment_freq = (GtkAdjustment*)gtk_adjustment_new(1.0, 1.0, 65535.0, 1.0, 100.0, 100.0); /* 1-65535 */
+    widget = gtk_spin_button_new(adjustment_freq, 1.0, 0);
     gtk_widget_show(widget);
-    gtk_entry_set_max_length(GTK_ENTRY(widget), 5); /* 0 - 65536 */
-    gtk_entry_set_text(GTK_ENTRY(widget), "1");
     gtk_table_attach(GTK_TABLE(table1), widget,
 		     1, 2, 4, 5, GTK_FILL, 0, 5, 5);
-    pane->frequency = GTK_ENTRY(widget);
+    pane->frequency = GTK_SPIN_BUTTON(widget);
 
     widget = gtk_frame_new(_("System:"));
     gtk_widget_show(widget);
@@ -284,7 +283,7 @@ static void cb_addwordpane_clearbutton_clicked(GtkButton *button, AddWordPane *p
     gtk_entry_set_text(GTK_ENTRY(pane->phonetic), "");
     gtk_entry_set_text(GTK_ENTRY(pane->literal), "");
     gtk_entry_set_text(GTK_ENTRY(pane->pos_narrow), "");
-    gtk_entry_set_text(GTK_ENTRY(pane->frequency), "1");
+    gtk_spin_button_set_value(GTK_SPIN_BUTTON(pane->frequency), 1);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pane->check_anthy), FALSE);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pane->check_canna), FALSE);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pane->check_prime), FALSE);
@@ -292,7 +291,7 @@ static void cb_addwordpane_clearbutton_clicked(GtkButton *button, AddWordPane *p
 
 static void cb_addwordpane_addbutton_clicked(GtkButton *button, AddWordPane *pane)
 {
-    gchar *phonetic, *literal, *pos;
+    const gchar *phonetic, *literal, *pos;
     gchar *defineword;
     char *euc_phonetic, *euc_literal;
     unsigned char *euc_defineword;
@@ -301,11 +300,11 @@ static void cb_addwordpane_addbutton_clicked(GtkButton *button, AddWordPane *pan
 
     phonetic = gtk_entry_get_text(pane->phonetic);
     literal  = gtk_entry_get_text(pane->literal);
-    pos = gtk_entry_get_text(pane->pos_narrow);
-    freq = atoi(gtk_entry_get_text(pane->frequency));
+    pos      = gtk_entry_get_text(pane->pos_narrow);
+    freq     = gtk_spin_button_get_value(pane->frequency);
 
     euc_phonetic = charset_convert(phonetic, "UTF-8", "EUC-JP");
-    euc_literal = charset_convert(literal, "UTF-8", "EUC-JP");
+    euc_literal  = charset_convert(literal, "UTF-8", "EUC-JP");
 
     if(euc_phonetic != NULL && euc_literal != NULL) {
 	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pane->check_anthy)) == TRUE) {
@@ -331,13 +330,14 @@ static void cb_addwordpane_addbutton_clicked(GtkButton *button, AddWordPane *pan
 	    ; /* do nothing */
 	}
     }
-
+/*
     if(phonetic != NULL)
 	g_free(phonetic);
     if(literal != NULL)
 	g_free(literal);
     if(pos != NULL)
 	g_free(pos);
+*/
     if(euc_phonetic != NULL)
 	g_free(euc_phonetic);
     if(euc_literal != NULL)
