@@ -54,9 +54,9 @@ static void cb_add_button_clicked (GtkButton *button,
     int ret;
 
     utf8_phonetic = gtk_entry_get_text(GTK_ENTRY(pane->phon));
-    utf8_literal = gtk_entry_get_text(GTK_ENTRY(pane->desc));
-    cclass_code = gtk_entry_get_text(GTK_ENTRY(pane->cclass_code));
-    freq = atoi(gtk_entry_get_text(GTK_ENTRY(pane->freq)));
+    utf8_literal  = gtk_entry_get_text(GTK_ENTRY(pane->desc));
+    cclass_code   = gtk_entry_get_text(GTK_ENTRY(pane->cclass_code));
+    freq = gtk_spin_button_get_value(pane->freq);
 
     euc_phonetic = charset_convert(utf8_phonetic, "UTF-8", "EUC-JP");
     euc_literal = charset_convert(utf8_literal, "UTF-8", "EUC-JP");
@@ -91,10 +91,12 @@ static void cb_add_button_clicked (GtkButton *button,
 	g_free(euc_phonetic);
     if(euc_literal != NULL)
 	g_free(euc_literal);
+/*
     if(utf8_phonetic != NULL)
 	g_free(utf8_phonetic);
     if(utf8_literal != NULL)
 	g_free(utf8_literal);
+*/
 }
 
 static void cb_clear_button_clicked (GtkButton *button,
@@ -103,6 +105,7 @@ static void cb_clear_button_clicked (GtkButton *button,
     gtk_entry_set_text(GTK_ENTRY(pane->phon), "");
     gtk_entry_set_text(GTK_ENTRY(pane->desc), "");
     gtk_entry_set_text(GTK_ENTRY(pane->cclass_code), "");
+    gtk_spin_button_set_value(GTK_SPIN_BUTTON(pane->freq), 1);
     gtk_option_menu_set_history(GTK_OPTION_MENU(pane->optmenu_cclass_code), 0);
 }
 
@@ -131,7 +134,8 @@ AnthyAddWordPane *anthy_addwordpane_new(void) {
     GtkWidget *alignment_cclass_code;
     GtkWidget *menu_cclass_code, *menuitem_cclass_code;
     GtkWidget *entry_phon, *entry_desc, *entry_cclass_code_narrow;
-    GtkWidget *entry_freq;
+    GtkWidget *spin_freq;
+    GtkAdjustment *adjustment_freq;
     GtkWidget *button_cclass_browse;
     GtkWidget *button_add, *button_clear;
     int cclass_code_num;
@@ -230,11 +234,10 @@ AnthyAddWordPane *anthy_addwordpane_new(void) {
     gtk_table_attach(GTK_TABLE(table1), label_freq,
 		     0, 1, 4, 5, GTK_FILL, 0, 5, 5);
 
-    entry_freq = gtk_entry_new();
-    gtk_widget_show(entry_freq);
-    gtk_entry_set_max_length(GTK_ENTRY(entry_freq), 5); /* 0 - 65536 */
-    gtk_entry_set_text(GTK_ENTRY(entry_freq), "1");
-    gtk_table_attach(GTK_TABLE(table1), entry_freq,
+    adjustment_freq = (GtkAdjustment*)gtk_adjustment_new(1.0, 1.0, 65535.0, 1.0, 100.0, 100.0); /* 1-65535 */
+    spin_freq = gtk_spin_button_new(adjustment_freq, 1.0, 0);
+    gtk_widget_show(spin_freq);
+    gtk_table_attach(GTK_TABLE(table1), spin_freq,
 		     1, 2, 4, 5, GTK_FILL, 0, 5, 5);
 
     vbox2 = gtk_vbutton_box_new();
@@ -258,7 +261,7 @@ AnthyAddWordPane *anthy_addwordpane_new(void) {
     pane->pane = GTK_WIDGET(hbox);
     pane->phon = GTK_WIDGET(entry_phon);
     pane->desc = GTK_WIDGET(entry_desc);
-    pane->freq = GTK_WIDGET(entry_freq);
+    pane->freq = GTK_WIDGET(spin_freq);
     pane->cclass_code = GTK_WIDGET(entry_cclass_code_narrow);
     pane->optmenu_cclass_code = GTK_WIDGET(optmenu_cclass_code);
     pane->add = GTK_WIDGET(button_add);
