@@ -26,7 +26,7 @@ gchar *charset_convert(const gchar *in,
 		       const gchar *outcode)
 {
     gsize rbytes, wbytes;
-    gchar *out;
+    gchar *out = NULL;
     GError *error = NULL;
 
     g_return_val_if_fail(in, NULL);
@@ -35,9 +35,10 @@ gchar *charset_convert(const gchar *in,
 
     out = g_convert(in, -1, outcode, incode, &rbytes, &wbytes, &error);
     if(error != NULL) {
-	g_printerr("g_convert failed: %s\n", error->message);
-	out = NULL;
+	g_printerr("g_convert failed: %s\nin: %s out: %s\n",
+		   error->message, in, out);
     }
+
     return out;
 }
 
@@ -61,17 +62,22 @@ gchar *utf8_convert(const gchar *in) {
 }
 
 gchar *utf8_to_eucjp(const gchar *utf8) {
-    gchar *eucjp;
+    gchar *eucjp = NULL;
     g_return_val_if_fail(utf8, NULL);
 
-    eucjp = charset_convert(utf8, "UTF-8", "EUC-JP");
+    if(g_utf8_validate(utf8, -1, NULL)) {
+	eucjp = charset_convert(utf8, "UTF-8", "EUC-JP");
+    }
+
+    /* XXX: must prepare fallbacks */
     return eucjp;
 }
 
 gchar *eucjp_to_utf8(const gchar *eucjp) {
     gchar *utf8;
     g_return_val_if_fail(eucjp, NULL);
-    
+
+    /* XXX: must check wheter eucjp is really EUC-JP */
     utf8 = charset_convert(eucjp, "EUC-JP", "UTF-8");
     return utf8;
 }
