@@ -27,7 +27,7 @@ void clean_gui(void) {
 
 gint main(gint argc, gchar *argv[]) {
     setlocale(LC_ALL, "");
-    bindtextdomain(PACKAGE, PACKAGE_LOCALE_DIR);
+    bindtextdomain(PACKAGE, LOCALEDIR);
     bind_textdomain_codeset(PACKAGE, "UTF-8");
     textdomain(PACKAGE);
     
