@@ -183,6 +183,7 @@ int create_topwindow(TopWindow *topwin) {
     gint menu_items_num = sizeof(menu_items) / sizeof(menu_items[0]);
     gint use_anthy;
     gint use_canna;
+    gint use_uim;
 
     topwin->window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 /*	gtk_window_set_default_size(GTK_OBJECT(win->window), 400, 200); */
@@ -206,6 +207,7 @@ int create_topwindow(TopWindow *topwin) {
 
     use_anthy = anthydic_init();
     use_canna = canna_init(NULL);
+    use_uim   = uimapi_init();
 
     if(use_anthy == 0) {
 	topwin->anthycontainer = g_malloc(sizeof(AnthyContainer));
@@ -256,13 +258,18 @@ int create_topwindow(TopWindow *topwin) {
 	topwin->addwordpane = NULL;
     }
 
-    topwin->uimconfigcontainer = uim_config_container_new();
-    if(topwin->uimconfigcontainer != NULL) {
-	gtk_box_pack_start(GTK_BOX(vbox),
-			   (topwin->uimconfigcontainer)->container,
-			   TRUE, TRUE, 0);
+    if(use_uim == 0) {
+	topwin->uimconfigcontainer = uim_config_container_new();
+	if(topwin->uimconfigcontainer != NULL) {
+	    gtk_box_pack_start(GTK_BOX(vbox),
+			       (topwin->uimconfigcontainer)->container,
+			       TRUE, TRUE, 0);
+	}
+    } else {
+	GtkItemFactoryEntry entry = { N_("/Option/_Uim"), NULL, cb_menu_option_switch_imsystem, MAIN_MENU_OPTION_UIM, "/Option/Anthy" };
+	gtk_item_factory_delete_entry(main_menu_item_factory, &entry);
+	topwin->uimconfigcontainer = NULL;
     }
-
     return 0;
 }
 
