@@ -27,12 +27,10 @@
  *
  **/
 
-#include "wordlist_view.h"
-
-#include "intl.h"
-
 #include <gtk/gtk.h>
-#include <glib.h>
+
+#include "wordlist_view.h"
+#include "intl.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -115,7 +113,7 @@ static void wordlist_view_class_init(WordlistViewClass *klass) {
 				    PROP_CCLASS_CODE_SHOW,
 				    g_param_spec_boolean("cclass_code_show",
 							 _("Show conjection class code column"),
-							 _(""),
+							 _("to be written"),
 							 FALSE,
 							 G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
@@ -123,28 +121,28 @@ static void wordlist_view_class_init(WordlistViewClass *klass) {
 				    PROP_FREQ_SHOW,
 				    g_param_spec_boolean("freq_show",
 							 _("Show freq column"),
-							 _(""),
+							 _("to be written"),
 							 FALSE,
 							 G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
     g_object_class_install_property(gobject_class,
 				    PROP_OKURI_SHOW,
 				    g_param_spec_boolean("okuri_show",
 							 _("Show okuri column"),
-							 _(""),
+							 _("to be written"),
 							 FALSE,
 							 G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
     g_object_class_install_property(gobject_class,
 				    PROP_EDITABLE,
 				    g_param_spec_boolean("editable",
-							 _(""),
-							 _(""),
+							 _("to be written"),
+							 _("to be written "),
 							 FALSE,
 							 G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
     g_object_class_install_property(gobject_class,
 				    PROP_SELECTION_MODE,
 				    g_param_spec_enum("selection_mode",
-						      _(""),
-						      _(""),
+						      _("to be written"),
+						      _("to be written"),
 						      GTK_TYPE_SELECTION_MODE,
 						      GTK_SELECTION_SINGLE,
 						      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
@@ -193,11 +191,23 @@ static void wordlist_view_init(WordlistView *view) {
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
 		      GINT_TO_POINTER(WORDLIST_PHON));
-    column = gtk_tree_view_column_new_with_attributes(_("Phonetic"), renderer,
+
+    column = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_title (column, _("Phonetic"));
+    gtk_tree_view_column_pack_start(column, renderer, TRUE);
+    gtk_tree_view_column_set_visible(column, TRUE);
+    gtk_tree_view_column_set_attributes(column, renderer,
+					"text", WORDLIST_PHON,
+					"editable", WORDLIST_EDITABLE,
+					NULL);
+
+/*
+    column = gtk_tree_view_column_new_with_attributes("Phonetic", renderer,
 						      "text", WORDLIST_PHON,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
-    gtk_tree_view_column_set_visible(column, TRUE);
+*/
+
     gtk_tree_view_append_column(view->view, column);
     view->phon_column = column;
 
@@ -208,12 +218,12 @@ static void wordlist_view_init(WordlistView *view) {
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
 		      GINT_TO_POINTER(WORDLIST_DESC));
-    column = gtk_tree_view_column_new_with_attributes(_("Literal"),
-						      renderer,
+    column = gtk_tree_view_column_new_with_attributes("Literal", renderer,
 						      "text", WORDLIST_DESC,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
     gtk_tree_view_append_column(view->view, column);
+    gtk_tree_view_column_set_title(column, _("Literal"));
     gtk_tree_view_column_set_visible(column, TRUE);
     view->desc_column = column;
 
@@ -224,12 +234,12 @@ static void wordlist_view_init(WordlistView *view) {
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
 		      GINT_TO_POINTER(WORDLIST_CCLASS_CODE));
-    column = gtk_tree_view_column_new_with_attributes(_("Part of Speech"),
-						      renderer,
+    column = gtk_tree_view_column_new_with_attributes("Part of Speech", renderer,
 						      "text", WORDLIST_CCLASS_CODE,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
     gtk_tree_view_column_set_visible(column, FALSE);
+    gtk_tree_view_column_set_title(column, _("Part of Speech"));
     gtk_tree_view_append_column(view->view, column);
     view->cclass_code_column = column;
 
@@ -240,21 +250,23 @@ static void wordlist_view_init(WordlistView *view) {
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
 		      GINT_TO_POINTER(WORDLIST_FREQ));
-    column = gtk_tree_view_column_new_with_attributes(_("Frequency"), renderer,
+    column = gtk_tree_view_column_new_with_attributes("Frequency", renderer,
 						      "text", WORDLIST_FREQ,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
     gtk_tree_view_column_set_visible(column, FALSE);
+    gtk_tree_view_column_set_title(column, _("Frequency"));
     gtk_tree_view_append_column(view->view, column);
     view->freq_column = column;
 
     /* Okuri */
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Okuri"), renderer,
+    column = gtk_tree_view_column_new_with_attributes("Okuri", renderer,
 						      "text", WORDLIST_OKURI,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
     gtk_tree_view_append_column(view->view, column);
+    gtk_tree_view_column_set_title(column, _("Okuri"));
     gtk_tree_view_column_set_visible(column, FALSE);
     view->okuri_column = column;
 
