@@ -33,11 +33,16 @@
 #ifndef __WORDLIST_VIEW_H__
 #define __WORDLIST_VIEW_H__
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif /* HAVE_CONFIG_H */
+
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtktreemodel.h>
 #include <gtk/gtktreeview.h>
 
 #include "word.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif
